summaryrefslogtreecommitdiffstats
path: root/generic/tkBind.c
diff options
context:
space:
mode:
authordgp <dgp@users.sourceforge.net>2001-08-01 16:21:11 (GMT)
committerdgp <dgp@users.sourceforge.net>2001-08-01 16:21:11 (GMT)
commit98ea3cb2214b51432f38f6ea50c1c429397281cc (patch)
tree38846cbe94cc8aac068898282ced4624f130770e /generic/tkBind.c
parent7e9aececf720b6f0e20157366f8e977ad2378ddd (diff)
downloadtk-98ea3cb2214b51432f38f6ea50c1c429397281cc.zip
tk-98ea3cb2214b51432f38f6ea50c1c429397281cc.tar.gz
tk-98ea3cb2214b51432f38f6ea50c1c429397281cc.tar.bz2
Merged changes from feature branch dgp-privates-into-namespace,
implementing TIP 44. All Tk commands and variables matching tk[A-Z]* are now in the ::tk namespace.
Diffstat (limited to 'generic/tkBind.c')
-rw-r--r--generic/tkBind.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/generic/tkBind.c b/generic/tkBind.c
index d06d246..f0627de 100644
--- a/generic/tkBind.c
+++ b/generic/tkBind.c
@@ -11,7 +11,7 @@
* See the file "license.terms" for information on usage and redistribution
* of this file, and for a DISCLAIMER OF ALL WARRANTIES.
*
- * RCS: @(#) $Id: tkBind.c,v 1.15 2001/03/30 21:52:28 hobbs Exp $
+ * RCS: @(#) $Id: tkBind.c,v 1.16 2001/08/01 16:21:11 dgp Exp $
*/
#include "tkPort.h"
@@ -293,7 +293,7 @@ typedef struct PhysicalsOwned {
* One of the following structures exists for each interpreter. This
* structure keeps track of the current display and screen in the
* interpreter, so that a script can be invoked whenever the display/screen
- * changes (the script does things like point tkPriv at a display-specific
+ * changes (the script does things like point tk::Priv at a display-specific
* structure).
*/
@@ -2545,16 +2545,16 @@ ExpandPercents(winPtr, before, eventPtr, keySym, dsPtr)
*
* This procedure is invoked whenever the current screen changes
* in an application. It invokes a Tcl procedure named
* "tkScreenChanged", passing it the screen name as argument.
* tkScreenChanged does things like making the tkPriv variable
* point to an array for the current display.
*
* Results:
* None.
*
* Side effects:
* Depends on what tkScreenChanged does. If an error occurs
* them tkError will be invoked.
*
*----------------------------------------------------------------------
*/
@@ -2571,7 +2571,7 @@ ChangeScreen(interp, dispName, screenIndex)
char screen[TCL_INTEGER_SPACE];
Tcl_DStringInit(&cmd);
- Tcl_DStringAppend(&cmd, "tkScreenChanged ", 16);
+ Tcl_DStringAppend(&cmd, "tk::ScreenChanged ", 18);
Tcl_DStringAppend(&cmd, dispName, -1);
sprintf(screen, ".%d", screenIndex);
Tcl_DStringAppend(&cmd, screen, -1);
@@ -2545,16 +2545,16 @@ ExpandPercents(winPtr, before, eventPtr, keySym, dsPtr)
* This procedure is invoked whenever the current screen changes
* in an application. It invokes a Tcl procedure named
- * "tkScreenChanged", passing it the screen name as argument.
- * tkScreenChanged does things like making the tkPriv variable
+ * "tk::ScreenChanged", passing it the screen name as argument.
+ * tk::ScreenChanged does things like making the tk::Priv variable
* point to an array for the current display.
*
@@ -2545,16 +2545,16 @@ ExpandPercents(winPtr, before, eventPtr, keySym, dsPtr)
*
* Side effects:
- * Depends on what tkScreenChanged does. If an error occurs
- * them tkError will be invoked.
+ * Depends on what tk::ScreenChanged does. If an error occurs
+ * them bgerror will be invoked.
*
*----------------------------------------------------------------------